@@ -81,8 +81,8 @@ class Discount(MasterDataMixin, models.Model):
     """
     class Meta:
         db_table = 'discounts'
-        verbose_name = _("adókevezmény")
-        verbose_name_plural = _("adókevezmények")
+        verbose_name = _("adókedvezmény")
+        verbose_name_plural = _("adókedvezmények")
 
     tax = models.ForeignKey(
         to=Tax,
